#!/bin/sh

# This helper script will handle deploying a s3 bucket
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

if [ -z "${bucketName}" ]; then
  echo "Must set env bucketName"
  exit 1
fi

run_cmd cp /etc/config/bucket-policy.json /terraform/

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars


if [ "${s3Events}" == "true" ]; then
  if [ "${destinationResource}" == "lambda" ]; then
     echo "lambda_arn =  \"$arn\" " >> ${tfAdditionalVarsFile}
  fi
  if [ "${destinationResource}" == "sqs" ]; then
     echo "sqs_arn = \"$arn\" " >> ${tfAdditionalVarsFile}
  fi
  if [ "${destinationResource}" == "sns" ]; then
     echo "sns_arn = \"$arn\" " >> ${tfAdditionalVarsFile}
  fi
fi

if [ "${logging}" == "true" ]; then

  echo "logging_bucket_name =  \"$loggingBucketName\" " >> ${tfAdditionalVarsFile}
fi

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get bucket_domain_name bucketDomainName
terraform_get bucket_regional_domain_name bucketRegionalDomainName
terraform_get read_only_policy readOnlyPolicy
terraform_get read_write_policy readWritePolicy
terraform_get bucket_lifecycle_policy bucketLifecyclePolicy

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  BUCKET_DOMAIN_NAME: ${bucketDomainName}
  BUCKET_REGIONAL_DOMAIN_NAME: ${bucketRegionalDomainName}
  ReadOnlyPolicy: ${readOnlyPolicy}
  ReadWritePolicy: ${readWritePolicy}
  BucketLifecyclePolicy: ${bucketLifecyclePolicy}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
